@@ -227,6 +227,11 @@ ID = 'id'
 F = 'f' # format
 NULLABLE = 'nullable'
 EDITABLE = 'editable'
+ADVANCED_QUERY_CAPABILITIES = 'advancedQueryCapabilities'
+SUPPORTS_PAGINATION = 'supportsPagination'
+RESULTOFFSET = 'resultOffset'
+ORDER_BY_FIELDS = 'orderByFields'
+EXCEED_TRANSFER_LIMIT = 'exceededTransferLimit'
 
 # misc
 DETAILS = 'details'
@@ -420,7 +425,7 @@ GEOM_CODE = {v:k for k,v in six.iteritems(GEOM_DICT)}
 BASE_PATTERN = 'http*://*/rest/services*'
 PORTAL_BASE_PATTERN = 'http*://*/sharing/rest*'
 PORTAL_SERVICES_PATTERN = 'http*://*/sharing/servers/*/rest/services/*'
-VERSION = '2.1.3'
+VERSION = '2.2'
 PACKAGE_NAME = 'restapi'
 USER_AGENT = '{}/{} (Python)'.format(PACKAGE_NAME, VERSION)
 GET = 'GET'
